%define upstream_name systemd-kcm

Name:           kcmsystemd
Version:        1.2.1
Release:        %mkrel 9
License:        GPLv3+
Group:          Graphical desktop/KDE
Summary:        Systemd control module for KDE
Url:            https://www.linux-apps.com/content/show.php/Kcmsystemd?content=161871
Source0:        https://dl.opendesktop.org/api/files/download/id/1466630746/161871-%{upstream_name}-%{version}.tar.gz
Patch0:         systemd-kcm-1.2.1-fix-build-against-qt-5.11.0.patch

BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5DBus)
BuildRequires:  pkgconfig(Qt5Widgets)

BuildRequires:  kf5-macros
BuildRequires:  cmake(KF5Auth)
BuildRequires:  cmake(KF5ConfigWidgets)
BuildRequires:  cmake(KF5CoreAddons)
BuildRequires:  cmake(KF5Crash)
BuildRequires:  cmake(KF5I18n)
BuildRequires:  cmake(KF5KIO)
BuildRequires:  cmake(KF5WidgetsAddons)

BuildRequires:  boost-devel
BuildRequires:  pkgconfig(libsystemd)

Provides:       %{upstream_name} = %{version}-%{release}

# for /usr/share/kservices5/settings-system-administration.desktop
# That file was previously shipped in this package, but now upstreamed to
# plasma-systemsettings 5.16.90.
Requires:       systemsettings >= 5.16.90

%description
Systemd control module for Plasma. Provides a graphical frontend
for the systemd daemon, which allows viewing and controlling
systemd units, as well as modifying configuration files.

Integrates in the System Settings dialogue in Plasma 5.

%files -f %{name}.lang
%doc NEWS README.md
%license COPYING
%{_libexecdir}/kauth/kcmsystemdhelper
%{_datadir}/dbus-1/system.d/org.kde.kcontrol.kcmsystemd.conf
%{_datadir}/dbus-1/system-services/org.kde.kcontrol.kcmsystemd.service
%{_datadir}/polkit-1/actions/org.kde.kcontrol.kcmsystemd.policy
%{_qt5_plugindir}/kcm_systemd.so
%{_kf5_services}/*.desktop

#--------------------------------------------------------------------

%prep
%setup -qn %{upstream_name}-%{version}
%autopatch -p1

%build
%cmake_kf5
%cmake_build

%install
%cmake_install

%find_lang %{name} --all-name

# fix file conflict with plasma-systemsettings >= 5.16.90
rm -f %{buildroot}%{_kf5_services}/settings-system-administration.desktop


%changelog
* Mon Jan 11 2021 daviddavid <daviddavid> 1.2.1-9.mga8
+ Revision: 1671068
- remove /usr/share/kservices5/settings-system-administration.desktop
- add systemsettings >= 5.16.90 as a dependency (which now ships this file)

* Thu Dec 17 2020 umeabot <umeabot> 1.2.1-8.mga8
+ Revision: 1658648
- Rebuild for new Qt5

* Sat Feb 15 2020 umeabot <umeabot> 1.2.1-7.mga8
+ Revision: 1528471
- Mageia 8 Mass Rebuild
+ wally <wally>
- build with new cmake macros

* Wed Aug 21 2019 daviddavid <daviddavid> 1.2.1-6.mga8
+ Revision: 1430799
- fix systemd conf file path

* Sat Mar 30 2019 umeabot <umeabot> 1.2.1-5.mga7
+ Revision: 1382140
- Qt5 Rebuild

* Sun Sep 23 2018 umeabot <umeabot> 1.2.1-4.mga7
+ Revision: 1298455
- Mageia 7 Mass Rebuild

* Sun Jul 01 2018 daviddavid <daviddavid> 1.2.1-3.mga7
+ Revision: 1241120
- add upstream patch to fix build with new Qt5 >= 5.11.0

* Tue Aug 01 2017 pterjan <pterjan> 1.2.1-2.mga7
+ Revision: 1133494
- Fix for new find_lang

* Thu Sep 15 2016 daviddavid <daviddavid> 1.2.1-1.mga6
+ Revision: 1053117
- new version: 1.2.1
- update URL and Source URL
- update BRs list

* Sat Dec 26 2015 daviddavid <daviddavid> 1.1.0-4.mga6
+ Revision: 915353
- rebuild for new boost 1.60.0

* Sat Sep 26 2015 daviddavid <daviddavid> 1.1.0-3.mga6
+ Revision: 883728
- rebuild for new boost 1.59.0

* Sun Aug 02 2015 daviddavid <daviddavid> 1.1.0-2.mga6
+ Revision: 860555
- rebuild for new boost-1.58.0

* Mon Jul 06 2015 neoclust <neoclust> 1.1.0-1.mga6
+ Revision: 851768
- New version 1.1.0

* Wed Oct 15 2014 umeabot <umeabot> 0.7.0-3.mga5
+ Revision: 748836
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.7.0-2.mga5
+ Revision: 680956
- Mageia 5 Mass Rebuild

* Mon Sep 08 2014 lmenut <lmenut> 0.7.0-1.mga5
+ Revision: 673396
- update to 0.7.0

* Fri Mar 28 2014 dglent <dglent> 0.6.0-1.mga5
+ Revision: 609061
- New version 0.6.0

* Sat Mar 15 2014 dglent <dglent> 0.5.0-1.mga5
+ Revision: 603956
- Exclude providing unversioned library
- imported package kcmsystemd

